Index: runtime/bin/output_stream.dart |
diff --git a/runtime/bin/output_stream.dart b/runtime/bin/output_stream.dart |
index 02a00f8e367bcc712004b00e2da91926b38d7a9c..41743a84f4cb5d7f47d29ec1511ad16a55376397 100644 |
--- a/runtime/bin/output_stream.dart |
+++ b/runtime/bin/output_stream.dart |
@@ -1,4 +1,4 @@ |
-// Copyright (c) 2011, the Dart project authors. Please see the AUTHORS file |
+// Copyright (c) 2012, the Dart project authors. Please see the AUTHORS file |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
@@ -9,7 +9,7 @@ |
* An output stream provides internal buffering of the data written |
* through all calls to [write] and [writeFrom] if data cannot be |
* written immediately to the communication channel. The callback set |
* through [noPendingWriteHandler] can be used to to keep the rate of |
* writing in sync with the rate the system can actually write data to |
* the underlying communication channel. |
*/ |
@@ -59,19 +59,19 @@ interface OutputStream { |
* writing in sync with the rate the system can write data to the |
* underlying communication channel. |
*/ |
- void set noPendingWriteHandler(void callback()); |
+ void set onNoPendingWrites(void callback()); |
/** |
* Sets the handler that gets called when the underlying |
* communication channel has been closed and no more data can be |
* send. |
*/ |
- void set closeHandler(void callback()); |
+ void set onClosed(void callback()); |
/** |
* Sets the handler that gets called when the underlying |
* communication channel gets into some kind of error situation. |
*/ |
- void set errorHandler(void callback()); |
+ void set onError(void callback()); |
} |
@@ -9,7 +9,7 @@ |
* through all calls to [write] and [writeFrom] if data cannot be |
* written immediately to the communication channel. The callback set |
- * through [noPendingWriteHandler] can be used to to keep the rate of |
+ * through [onNoPendingWrites] can be used to to keep the rate of |
* writing in sync with the rate the system can actually write data to |
* the underlying communication channel. |